/*
 * NASPRO - The NASPRO Architecture for Sound Processing
 * A collection of bridges to LV2
 * LADSPA bridge
 *
 * Copyright (C) 2007-2011 NASPRO bridges development team
 *
 * See the COPYING file for license conditions.
 */

#include <stdlib.h>
#include <string.h>

#include <math.h>

#ifdef __HAIKU__
#include <FindDirectory.h>
#include <fs_info.h>
#endif

#include <ladspa.h>

#include <NASPRO/brit/lib.h>

#define API	NACORE_PUBLIC NACORE_EXPORT

#include "config.h"

#ifdef HAVE_DYNMANIFEST_H
# include <lv2/lv2plug.in/ns/ext/dynmanifest/dynmanifest.h>
#else
# include <lv2/lv2plug.in/ns/ext/dyn-manifest/dyn-manifest.h>
#endif

#include "bridge.h"
#include "pluglib.h"
#include "plugin.h"
#include "lv2api.h"
